@@ -306,8 +306,9 @@ class Artifacts:
         return True
 
     # Artifact 객체를 기반으로 Artifact에 등록된 모든 엔트리의 다운로드 수행
-    def download(self) -> str:
-        local_root_path = self.get_download_dir(with_repo_tag=False)
+    def download(self, local_root_path:str=None) -> str:
+        if not local_root_path:
+            local_root_path = self.get_download_dir(with_repo_tag=False)
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
         for idx, entry in enumerate(self.entry_list):
             entry.download(local_root_path, self.id, self.run.team_name,
