@@ -1,5 +1,5 @@
 from __future__ import annotations
-
+from deepdriver import logger
 experiment: Experiment = None
 
 
@@ -10,6 +10,8 @@ def set_experiment(experiment_: Experiment) -> None:
 
 def get_experiment() -> Experiment:
     global experiment
+    if not experiment:
+        logger.warning("experiment is None")
     return experiment
 
 
