@@ -64,7 +64,7 @@ class Table(Media):
     def upload_file(self, run: Run, key_name: str) -> None:
         # Table의 data인 deepdriver.dataframe으로부터 column과 data를 가져와서 json형태의 파일로 저장
         local_path = self.get_local_path(run.run_id, key_name)
-        digest, size = self.file_dump(local_path)
+        digest, size = self.file_dump(local_path, key_name)
 
         # 저장한 파일을 Interface.py의 upoad_file을 호출하여 전송
         root_path = self.get_root_path(run.run_id)
